﻿#WORKUNIT('name', 'FDA_Drugs - Find Drugs By Ingredient');
import std;
import FDA_Drugs;
//
// NOTE:
// Please follow the instructions at the top of BWR_ETL first!  (The data needs to already
// have been ingested into the system before trying to run this BWR.)
//
// This BWR will display information about all drugs that contain a particular
// ingredient.  It demonstrates how to use the FDA Drugs data.
//

// Change this value to locate other ingredients.
ActiveIngredient := std.Str.ToUpperCase('Loratadine');


// Find all products with the active ingredient.
dsProducts := FDA_Drugs.Datasets.dsProduct(std.Str.Find(ActiveIngred,ActiveIngredient,1)>0);

// Put together all of the data for the found products and present in a single flattened layout.
L_Results := RECORD
		// From L_Product
		STRING6		ApplNo;
		STRING3		ProductNo;
		STRING255	Form;
		STRING240	Dosage;
		UNSIGNED1	ProductMktStatus;  // (1=prescription, 2=OTC, 3=discontinued, 4=tentative approval)
		STRING100	TECode;
		BOOLEAN		ReferenceDrug;
		STRING125	DrugName;
		STRING255	ActiveIngred;
		// From L_Application (ApplNo is the key)
		STRING5		ApplType;
		STRING50	SponsorApplicant;
		BOOLEAN		MostRecentLabelAvailableFlag;
		BOOLEAN		CurrentPatentFlag;
		STRING10	ActionType;
		STRING3		ChemicalType;
		STRING2		TherapeuticPotential;
		STRING1		OrphanCode;
		// From L_ChemicalType_Lookup (map ChemicalType to ChemicalTypeCode)
		INTEGER4	ChemicalTypeID							:= 0;
		STRING200	ChemicalTypeDescription			:= '';
		// From L_ReviewClass_Lookup (map TherapeuticPotential to ReviewCode)
		INTEGER4	ReviewClassID								:= 0;
		STRING100	LongDescription							:= '';
		STRING100	ShortDescription						:= '';
		// From L_RegActionDate (ApplNo is the key)
		STRING4		InDocTypeSeqNo							:= '';
		INTEGER4	DuplicateCounter						:= 0;
		STRING19	ActionDate									:= '';
		STRING4		DocType											:= '';
		// From L_DocType_Lookup (map DocType)
		STRING50	DocTypeDesc									:= '';
		// From L_AppDoc (ApplNo is the key)
		INTEGER4		AppDocID									:= 0;
		STRING4			SeqNo											:= '';
		STRING50		AppDocType								:= '';
		STRING100		DocTitle									:= '';
		STRING200		DocURL										:= '';
		STRING19		DocDate										:= '';
		// From L_AppDocType_Lookup (map AppDocType)
		INTEGER4		SortOrder									:= 0;
END;

// Convert to L_Results layout, and join Product and Application data.
//   This data is already distributed on ApplNo, so can do a LOCAL join.
dsProductApplication :=
	JOIN(dsProducts, FDA_Drugs.Datasets.dsApplication,
			 LEFT.ApplNo=RIGHT.ApplNo,
			 TRANSFORM(L_Results, SELF := LEFT; SELF := RIGHT;),
			 LOCAL);

// Join in the RegActionDate and AppDoc data
dsProdAppRegActionDate :=
	JOIN(dsProductApplication, FDA_Drugs.Datasets.dsRegActionDate,
			 LEFT.ApplNo=RIGHT.ApplNo,
			 TRANSFORM(L_Results, SELF := LEFT; SELF := RIGHT;),
			 LOCAL);
dsProdAppRegAppDoc :=
	JOIN(dsProdAppRegActionDate, FDA_Drugs.Datasets.dsAppDoc,
			 LEFT.ApplNo=RIGHT.ApplNo,
			 TRANSFORM(L_Results,
								 SELF.AppDocType := RIGHT.DocType;
								 SELF := LEFT; SELF := RIGHT;),
			 LOCAL);

// Dedup
dsDeduppedResults := DEDUP(SORT(dsProdAppRegAppDoc, RECORD), RECORD);

// Join in the lookups of the various explanatory code values.
//  Use LEFT OUTER join because these values are sometimes optional.
dsChemTypeLookup :=
	JOIN(dsDeduppedResults, FDA_Drugs.Datasets.dsChemicalType_Lookup,
			 LEFT.ChemicalType=RIGHT.ChemicalTypeCode,
			 TRANSFORM(L_Results, SELF := LEFT; SELF := RIGHT;),
			 LEFT OUTER, LOOKUP);
dsReviewClassLookup :=
	JOIN(dsChemTypeLookup, FDA_Drugs.Datasets.dsReviewClass_Lookup,
			 LEFT.TherapeuticPotential=RIGHT.ReviewCode,
			 TRANSFORM(L_Results, SELF := LEFT; SELF := RIGHT;),
			 LEFT OUTER, LOOKUP);
dsDocTypeLookup :=
	JOIN(dsReviewClassLookup, FDA_Drugs.Datasets.dsDocType_Lookup,
			 LEFT.DocType=RIGHT.DocType,
			 TRANSFORM(L_Results, SELF := LEFT; SELF := RIGHT;),
			 LEFT OUTER, LOOKUP);
dsAppDocTypeLookup :=
	JOIN(dsDocTypeLookup, FDA_Drugs.Datasets.dsAppDocType_Lookup,
			 LEFT.AppDocType=RIGHT.AppDocType,
			 TRANSFORM(L_Results, SELF := LEFT; SELF := RIGHT;),
			 LEFT OUTER, LOOKUP);

// Sort the results
dsResults := SORT(dsAppDocTypeLookup, ApplNo,ProductMktStatus,InDocTypeSeqNo,SeqNo,SortOrder,ActionType,ActionDate);

OUTPUT(COUNT(dsResults));
OUTPUT(dsResults);
